#
# spec file for package libyuv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libyuv
VCS: https://src.suse.de/SLFO-pool/libyuv#adb45f710bbbbcf8af351c7deec0c3bfae302c2a442033c1293afd0dfb50ddca
Version:        20230517+a377993
Release:        160000.1.3
Summary:        YUV scaling and conversion library
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
URL:            https://chromium.googlesource.com/libyuv/libyuv/
Source0:        %{name}-%{version}.tar.xz
Source99:       baselibs.conf
# from Fedora
Patch0:         Use-a-proper-so-version.patch
Patch1:         Link-against-shared-library.patch
Patch2:         Disable-static-library.patch
Patch3:         Install-missing-yuvconstants-binary.patch
Patch4:         Use-library-suffix-during-installation.patch
Patch5:         cmake-minimum-required.patch
Patch6:         convert_test-little-endian.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libjpeg)

%description
libyuv is a project for YUV image scaling and conversion. It can
convert between RGB and YUV, scale images with point/bilinear/box
filter, rotate by 90/180/270°, and offers SSE/NEON/MSA acceleration.

%package -n libyuv0
Summary:        YUV scaling and conversion library
Group:          System/Libraries

%description -n libyuv0
libyuv is a project for YUV image scaling and conversion.

%package devel
Summary:        Development files for the YUV scaling and conversion library
Group:          Development/Libraries/C and C++
Requires:       libyuv0%{_isa} = %{version}

%description devel
This package contains the development files
for the YUV scaling and conversion library.

%package tools
Summary:        Command line utilities from libyuv
Group:          Productivity/Graphics/Other

%description tools
libyuv is a project for YUV image scaling and conversion. It can
convert between RGB and YUV, scale images with point/bilinear/box
filter, rotate by 90/180/270°, and offers SSE/NEON/MSA acceleration.

This package contains the yuvconvert and yuvconstants commandline programs.

%prep
%autosetup -p1

%build
rversion=`grep --perl-regex --only-matching "(?<=LIBYUV_VERSION )[0-9]+" include/libyuv/version.h`
cat > %{name}.pc << EOF
prefix=%{_prefix}
exec_prefix=\${prefix}
includedir=%{_includedir}
libdir=%{_libdir}

Name:           %{name}
VCS: https://src.suse.de/SLFO-pool/libyuv#adb45f710bbbbcf8af351c7deec0c3bfae302c2a442033c1293afd0dfb50ddca
Description:  %{summary}
Version:        ${rversion}
Libs:  -lyuv
EOF

# Compile all unit tests, not only the default set.
export CFLAGS="%{optflags} -DENABLE_ROW_TESTS -DENABLE_FULL_TESTS"
export CXXFLAGS="$CFLAGS"

OUR_CMAKE_FLAGS=' -DCMAKE_SKIP_RPATH:BOOL=ON ' #do not put bogus runpath in installed executables
OUR_CMAKE_FLAGS+=' -DUNIT_TEST:BOOL=ON '
%cmake $OUR_CMAKE_FLAGS
%cmake_build

%install
%cmake_install
install -pDm0644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%ldconfig_scriptlets -n libyuv0

%check
LD_LIBRARY_PATH=$PWD/build ./build/libyuv_unittest

%files -n libyuv0
%{_libdir}/libyuv.so.*

%files devel
%license LICENSE
%{_libdir}/libyuv.so
%{_includedir}/%{name}
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/%{name}.pc

%files tools
%{_bindir}/yuvconvert
%{_bindir}/yuvconstants

%changelog
* Mon May 22 2023 jengelh@inai.de
- Trim redundancies and compact descriptions.
* Sun May 21 2023 brunopitrus@hotmail.com
- Update to snapshot 20230517+a377993:
  * ARGBToI420Alpha function to convert ARGB to I420 with Alpha
  * Enable I{422,444}AlphaToARGBRow_RVV & ARGBAttentuateRow_RVV
  * Bump version and apply clang format
  * Enable ARGBToYMatrixRow_RVV/RGBAToYMatrixRow_RVV/RGBToYMatrixRow_RVV
  * Enable RVV if qemu is detected
  * Add ARGBToRAWRow_RVV, ARGBToRGB24Row_RVV, RGB24ToARGBRow_RVV
  * YUY2ToNV12 using YUY2ToY and YUY2ToNVUV
  * Remove old cipd clobber gclient hook.
  * Roll chromium_revision 004bde16df..28dca358ed (1051775:1052960)
  * Roll chromium_revision 7d683aeda8..004bde16df (1050091:1051775)
  * [code-health] Migrate presubmit to python3
  * Enable unlimited data for YUV to RGB
  * Roll chromium_revision 829c6df33d..7d683aeda8 (945687:1050098th
- Add libyuv-tools package
- Run test suite in %%check
- drop Don-t-install-conversion-tool.patch
- add Install-missing-yuvconstants-binary.patch
- add cmake-minimum-required.patch
- drop Link-main-library-against-libjpeg.patch applied upstream
- add convert_test-little-endian.patch
* Thu Oct 27 2022 gmbr3@opensuse.org
- Update to version 20220920+f9fda6e:
  * Fix shift amount for SSSE3 assembly for I012 format conversions
  * 10/12 bit YUV replicate upper bits to low bits before converting to RGB
  * Fix immediate offsets for row_neon build on gcc
* Thu Oct 20 2022 gmbr3@opensuse.org
- Update to version 20220920+248172e:
  * I422ToRGB24, I422ToRAW, I422ToRGB24MatrixFilter conversion functions added.
  * Remove include resource.h for Fuchsia build
  * I420ToRGB24MatrixFilter function added
  * SSE2 MM21->YUY2 conversion
  * MM21ToYUY2 and  ABGRToJ420 conversion
  * AB64ToARGB fix for inplace conversion
  * Bump up version to 1838
  * Add I422ToRGB565Matrix
  * RAWToJ400 require multiple of 16 pixels for NEON
  * row_neon*: Explicitly initialize pad in RgbConstants
  * Fix MSVC warnings by adding casts
  * Define _CRT_SECURE_NO_WARNINGS if MSVC CRT is used
  * Reduce cmake verbosity and update min version
  * Set IMPORT_PREFIX to "lib" on Windows
  * Android.bp: Remove reference to LICENSE_THIRD_PARTY
  * Fix SSE2 version of ScalePlaneUp2_16_Bilinear
  * Disable bilinear 16 bit scale up for SSE2
  * Add .vpython3 to libyuv.
  * Switch from python to python3.
* Sat Oct  1 2022 gmbr3@opensuse.org
- Use YUV_VERSION for library VERSION and YUV_VER_MAJOR for
  SOVERSION
* Sun Sep 25 2022 gmbr3@opensuse.org
- Fix quoting in pkgconfig file
* Wed Aug  3 2022 gmbr3@opensuse.org
- Add baselibs.conf for libyuv0
* Fri Jul 29 2022 gmbr3@opensuse.org
- Initial packaging version 20220713+d248929c
- Add required patches:
  * Use-a-proper-so-version.patch
  * Link-against-shared-library.patch
  * Disable-static-library.patch
  * Don-t-install-conversion-tool.patch
  * Use-library-suffix-during-installation.patch
  * Link-main-library-against-libjpeg.patch
